pub enum FrontBack<A, B> {
Front(A),
Back(B),
}Expand description
This is the TokenGroup for BookEnds. We need to differentiate between features at the front of a word and features at the back of a word. Otherwise suffixes and prefixes would be identical.
Variants
Front(A)
the TokenGroup from running A on the front of the input
Back(B)
the TokenGroup from running B on the Back of the input